đ REFERENCE¶ Here is technical the documentation abouteach part of the application Architecture applicative Diagramme global Cartographie des composants Code Guidelines Use of French and English languages Accepted side effects Python and TypeScript coding guidelines Infrastructure, monitoring, CI/CD Provisioning the infrastructure CI/CD Documentation Monitoring Preview environments Postgresql Database Versions Databases PostgreSQL extensions Handling default values in the database Using SQL constraints Architecture Data Platform Task types Webapp Overall structure đ Useful Tools and Commands â ïž Important Points Open Data Changelog du jeu de donnĂ©es Open Data : « Acteurs de lâĂ©conomie circulaire - Que faire de mes objets et dĂ©chets » Jeu de donnĂ©es open data : acteurs Politique de version du jeu de donnĂ©es Open Data Organisation interne de la gestion des versions du jeu de donnĂ©es Open Data API Guidelines Structure How to add a new API Conventions Testing More details about API by router Security Security policy Monitoring Topics